@@ -1,3 +1,6 @@
+skip_on_cran()
+skip_if(!curl::has_internet())
+skip_if(httr::http_error("ourworldindata.org"))
 
 test_that("owid search gives object of class matrix and array", {
   search <- owid_search("gdp")
